@@ -37,6 +37,10 @@ REGEX_MODULE_ID = re.compile(
 def parse_module_id(id):
     # there will always a match
     m = re.match(REGEX_MODULE_ID, id)
+
+    if not m:
+        raise ValueError('Invalid module id: "' + id + '", format: <name>[@<version>][/<path>]')
+
     path = m.group(3) or ''
 
     if path == '/':
@@ -47,3 +51,10 @@ def parse_module_id(id):
         # version default to '*'
         m.group(2) or '*',
         path)
+
+# returns the max satisfied version of the range
+# @param {str} r Range
+# @param {list} versions The list of existing versions
+def max_satisfying(r, versions):
+    # returns the range directly temporarily for now
+    return r
